local harbour = ...

HarbourPrefix = "HARBOUR_V2"
CommonWindowPrefix = "CUSTOM_WINDOW_V2"
CommonDoorPrefix = "CUSTOM_DOOR_V2"

-- Apply building asset processor
harbour:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

harbour:registerAssetId("models/core.fbx/Prefab/CoreBuildingPart", HarbourPrefix .. "_CORE_BUILDING_PREFAB")

-- Register the harbour Core part
harbour:register({
	DataType = "BUILDING_PART",
	Id = HarbourPrefix .. "_CORE_BUILDING_PART",
	Name = HarbourPrefix .. "_CORE_BUILDING_NAME",
	Description = HarbourPrefix .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = HarbourPrefix .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
})

_LightTowerBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createCircle( 3.3, { 0, 0 }, 16 ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createCircle( 3.3, { 0, 0 }, 16 ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
}}
_DockBuildingZone = { ZoneEntryList = {
--            { Polygon = polygon.createRectangle( {16.5, 4.5} ),
--              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {16.5, 4.5} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
}}
_PontonBuildingZone = { ZoneEntryList = {
--            { Polygon = polygon.createRectangle( {6, 4.5} ),
--              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {6, 4.5} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
}}
_RampBuildingZone = { ZoneEntryList = {
--            { Polygon = polygon.createRectangle( {6, 4.5} ),
--              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {6, 4.5} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
}}
harbour:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")
harbour:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")

-- Register all harbour building parts and their properties
harbour:dofile("scripts/behavior_tree.lua")
harbour:dofile("scripts/job.lua")
harbour:dofile("scripts/compStaticBoat.lua")
harbour:dofile("scripts/compBoat.lua")
harbour:dofile("scripts/compSail.lua")
harbour:dofile("scripts/compOar.lua")
harbour:dofile("scripts/compGuardLocation.lua")
harbour:dofile("scripts/boat_parts.lua")

-- Register the Harbour monument
harbour:register({
    Id = HarbourPrefix .. "_VH",
    DataType = "BUILDING",
    AssetCoreBuildingPart = HarbourPrefix .. "_CORE_BUILDING_PART",
    Name = HarbourPrefix .. "_MONUMENT_NAME",
    Description = HarbourPrefix .. "_MONUMENT_DESC",
    BuildingType = "MONUMENT",
    BuildingPartSetList = {
		{
			Name = HarbourPrefix .. "_TERRAIN_NAME",
	                BuildingPartList = {
		            HarbourPrefix .. "_LIGHT_TOWER_ROOT_PART",
		            HarbourPrefix .. "_LIGHT_ROOF_A_PART",
		            CommonWindowPrefix .. "_DECORATION_SFENETRE_PART",
		            CommonWindowPrefix .. "_DECORATION_LFENETRE_PART",
		            CommonWindowPrefix .. "_DECORATION_PFENETRE_PART",
		            CommonWindowPrefix .. "_DECORATION_ARROWSLIT_PART",
		            HarbourPrefix .. "_DOCK_PART",
		            HarbourPrefix .. "_PONTOON_PART"
                        }
                },
		{
			Name = HarbourPrefix .. "_ENTRANCE_NAME",
	                BuildingPartList = {
 		            CommonDoorPrefix .. "_ENTRANCE_DOOR_A_PART",
  		            CommonDoorPrefix .. "_ENTRANCE_DOOR_B_PART",
		            HarbourPrefix .. "_RAMP_PART"
                        }
                },
                {
			Name = HarbourPrefix .. "_WATER_NAME",
	                BuildingPartList = {
		            HarbourPrefix .. "_BOAT_STATIC_PART",
		            HarbourPrefix .. "_BOAT_PART",
		            HarbourPrefix .. "_ROWING_PART"
--[[, -- for future usage
                            HarbourPrefix .. "_FLAG_RED_ROOT_PART",
                            HarbourPrefix .. "_FLAG_BLUE_ROOT_PART"
]]
                        }
                }
    },
    MaterialSetList = {
            {
                SetName = HarbourPrefix .. "_RED_ROOF", -- default materials
                MaterialList = {
                    HarbourPrefix .. "_RED_ROOF_MATERIAL"
                }
            },
            {
                SetName = HarbourPrefix .. "_BLUE_ROOF",
                MaterialList = {
                    HarbourPrefix .. "_BLUE_ROOF_MATERIAL"
                }
            },
            {
                SetName = HarbourPrefix .. "_BROWN_ROOF",
                MaterialList = {
                    HarbourPrefix .. "_BROWN_ROOF_MATERIAL"
                }
            },
            {
                SetName = HarbourPrefix .. "_GREY_ROOF",
                MaterialList = {
                    HarbourPrefix .. "_GREY_ROOF_MATERIAL"
                }
            },
            {
                SetName = HarbourPrefix .. "_GREY2_ROOF",
                MaterialList = {
                    HarbourPrefix .. "_GREY2_ROOF_MATERIAL"
                }
            }
    },
    IsManuallyUnlocked = false,
    IsDestructible = true,
    IsEditable = true,
    IsClearTrees = true
})
